==> llm-docs-0.1.2.tgz: package/scripts/migrate-to-shared.js <==
#!/usr/bin/env node

/**
 * Script to add @bluefly/shared to bfdocs
 * This script:
 * 1. Updates package.json to add @bluefly/shared
 * 2. Adds scripts for working with shared utilities
 */

import fs from 'fs';
import path from 'path';
import { fileURLToPath } from 'url';
import { execSync } from 'child_process';

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
const rootDir = path.resolve(__dirname, '..');

// Process package.json
function updatePackageJson() {
  const packageJsonPath = path.join(rootDir, 'package.json');
  console.log(`Updating ${packageJsonPath}...`);
  
  if (!fs.existsSync(packageJsonPath)) {
    console.error(`Error: ${packageJsonPath} not found`);
    process.exit(1);
  }
  
  const packageJson = JSON.parse(fs.readFileSync(packageJsonPath, 'utf8'));
  
  // Create backup
  fs.writeFileSync(`${packageJsonPath}.backup`, JSON.stringify(packageJson, null, 2));
  console.log(`Created backup at ${packageJsonPath}.backup`);
  
  let changed = false;
  
  // Add @bluefly/shared as a dependency if not exists
  if (!packageJson.dependencies) {
    packageJson.dependencies = {};
  }
  
  if (!packageJson.dependencies['@bluefly/shared']) {
    console.log('Adding @bluefly/shared dependency...');
    packageJson.dependencies['@bluefly/shared'] = '^0.1.1';
    changed = true;
  }
  
  // Add migrate:shared script if not exists
  if (!packageJson.scripts['migrate:shared']) {
    packageJson.scripts['migrate:shared'] = 'node scripts/migrate-to-shared.js';
    changed = true;
  }
  
  // Add test:shared script if not exists
  if (!packageJson.scripts['test:shared']) {
    packageJson.scripts['test:shared'] = 'node scripts/test-shared-utilities.js';
    changed = true;
  }
  
  if (changed) {
    fs.writeFileSync(packageJsonPath, JSON.stringify(packageJson, null, 2));
    console.log('Updated package.json successfully');
  } else {
    console.log('No changes needed in package.json');
  }
  
  return changed;
}

// Create test script for shared utilities
function createTestScript() {
  const testScriptPath = path.join(rootDir, 'scripts', 'test-shared-utilities.js');
  
  if (fs.existsSync(testScriptPath)) {
    console.log('Test script already exists, skipping...');
    return false;
  }
  
  const testScript = `#!/usr/bin/env node

/**
 * Script to test @bluefly/shared integration
 */

import { config, logger, errors } from '@bluefly/shared';

console.log('Testing @bluefly/shared integration...');

// Test config
console.log('\\nConfig module:');
console.log('- Available exports:', Object.keys(config));

// Test logger
console.log('\\nLogger module:');
console.log('- Available methods:', Object.keys(logger));

// Test errors
console.log('\\nErrors module:');
console.log('- Available exports:', Object.keys(errors));

console.log('\\n@bluefly/shared integration test passed!');
`;

  fs.writeFileSync(testScriptPath, testScript);
  console.log(`Created test script at ${testScriptPath}`);
  return true;
}

// Create documentation
function createDocumentation() {
  const docPath = path.join(rootDir, 'SHARED_UTILITIES.md');
  
  if (fs.existsSync(docPath)) {
    console.log('Documentation already exists, skipping...');
    return false;
  }
  
  const doc = `# Shared Utilities Integration

This project uses the \`@bluefly/shared\` package for common utilities.

## Available Modules

The shared package provides the following modules:

- \`config\`: Configuration management
- \`logger\`: Unified logging
- \`errors\`: Standard error handling
- \`http\`: Resilient HTTP client
- \`utils\`: Common utility functions

## Usage

Import the modules you need:

\`\`\`javascript
import { config, logger, errors } from '@bluefly/shared';

// Use config
const apiKey = config.get('api.key');

// Use logger
logger.info('Operation completed', { component: 'docs', operation: 'build' });

// Use errors
throw errors.createError('VALIDATION_ERROR', 'Invalid input');
\`\`\`

## Documentation

For more information, see the [shared package documentation](https://gitlab.bluefly.io/llm/bfcli/tree/main/shared).
`;

  fs.writeFileSync(docPath, doc);
  console.log(`Created documentation at ${docPath}`);
  return true;
}

// Main function
function main() {
  console.log('Starting @bluefly/shared integration...');
  
  const pkgChanged = updatePackageJson();
  const testScriptCreated = createTestScript();
  const docCreated = createDocumentation();
  
  if (pkgChanged || testScriptCreated || docCreated) {
    console.log('\nIntegration complete!');
    console.log('\nNext steps:');
    console.log('1. Run `npm install` to install @bluefly/shared');
    console.log('2. Run `npm run test:shared` to test the integration');
    console.log('3. Commit the changes');
  } else {
    console.log('\nNo changes were made. The project may already be integrated with @bluefly/shared.');
  }
}

main();

==> llm-docs-0.1.5.tgz: package/scripts/migrate-to-shared.js <==
#!/usr/bin/env node

/**
 * DEPRECATED: This migration script is no longer needed.
 * All @bluefly/shared-utils and @bluefly/shared dependencies have been 
 * replaced with local implementations to remove external dependencies.
 */

console.log('⚠️  This migration script is deprecated and no longer needed.');
console.log('All @bluefly dependencies have been replaced with local implementations.');
process.exit(0);

import fs from 'fs';
import path from 'path';
import { fileURLToPath } from 'url';
import { execSync } from 'child_process';

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
const rootDir = path.resolve(__dirname, '..');

// Process package.json
function updatePackageJson() {
  const packageJsonPath = path.join(rootDir, 'package.json');
  console.log(`Updating ${packageJsonPath}...`);
  
  if (!fs.existsSync(packageJsonPath)) {
    console.error(`Error: ${packageJsonPath} not found`);
    process.exit(1);
  }
  
  const packageJson = JSON.parse(fs.readFileSync(packageJsonPath, 'utf8'));
  
  // Create backup
  fs.writeFileSync(`${packageJsonPath}.backup`, JSON.stringify(packageJson, null, 2));
  console.log(`Created backup at ${packageJsonPath}.backup`);
  
  let changed = false;
  
  // Add @bluefly/shared as a dependency if not exists
  if (!packageJson.dependencies) {
    packageJson.dependencies = {};
  }
  
  if (!packageJson.dependencies['@bluefly/shared']) {
    console.log('Adding @bluefly/shared dependency...');
    packageJson.dependencies['@bluefly/shared'] = '^0.1.1';
    changed = true;
  }
  
  // Add migrate:shared script if not exists
  if (!packageJson.scripts['migrate:shared']) {
    packageJson.scripts['migrate:shared'] = 'node scripts/migrate-to-shared.js';
    changed = true;
  }
  
  // Add test:shared script if not exists
  if (!packageJson.scripts['test:shared']) {
    packageJson.scripts['test:shared'] = 'node scripts/test-shared-utilities.js';
    changed = true;
  }
  
  if (changed) {
    fs.writeFileSync(packageJsonPath, JSON.stringify(packageJson, null, 2));
    console.log('Updated package.json successfully');
  } else {
    console.log('No changes needed in package.json');
  }
  
  return changed;
}

// Create test script for shared utilities
function createTestScript() {
  const testScriptPath = path.join(rootDir, 'scripts', 'test-shared-utilities.js');
  
  if (fs.existsSync(testScriptPath)) {
    console.log('Test script already exists, skipping...');
    return false;
  }
  
  const testScript = `#!/usr/bin/env node

/**
 * Script to test @bluefly/shared integration
 */

import { config, logger, errors } from '@bluefly/shared';

console.log('Testing @bluefly/shared integration...');

// Test config
console.log('\\nConfig module:');
console.log('- Available exports:', Object.keys(config));

// Test logger
console.log('\\nLogger module:');
console.log('- Available methods:', Object.keys(logger));

// Test errors
console.log('\\nErrors module:');
console.log('- Available exports:', Object.keys(errors));

console.log('\\n@bluefly/shared integration test passed!');
`;

  fs.writeFileSync(testScriptPath, testScript);
  console.log(`Created test script at ${testScriptPath}`);
  return true;
}

// Create documentation
function createDocumentation() {
  const docPath = path.join(rootDir, 'SHARED_UTILITIES.md');
  
  if (fs.existsSync(docPath)) {
    console.log('Documentation already exists, skipping...');
    return false;
  }
  
  const doc = `# Shared Utilities Integration

This project uses the \`@bluefly/shared\` package for common utilities.

## Available Modules

The shared package provides the following modules:

- \`config\`: Configuration management
- \`logger\`: Unified logging
- \`errors\`: Standard error handling
- \`http\`: Resilient HTTP client
- \`utils\`: Common utility functions

## Usage

Import the modules you need:

\`\`\`javascript
import { config, logger, errors } from '@bluefly/shared';

// Use config
const apiKey = config.get('api.key');

// Use logger
logger.info('Operation completed', { component: 'docs', operation: 'build' });

// Use errors
throw errors.createError('VALIDATION_ERROR', 'Invalid input');
\`\`\`

## Documentation

For more information, see the [shared package documentation](https://gitlab.bluefly.io/llm/llmcli/tree/main/shared).
`;

  fs.writeFileSync(docPath, doc);
  console.log(`Created documentation at ${docPath}`);
  return true;
}

// Main function
function main() {
  console.log('Starting @bluefly/shared integration...');
  
  const pkgChanged = updatePackageJson();
  const testScriptCreated = createTestScript();
  const docCreated = createDocumentation();
  
  if (pkgChanged || testScriptCreated || docCreated) {
    console.log('\nIntegration complete!');
    console.log('\nNext steps:');
    console.log('1. Run `npm install` to install @bluefly/shared');
    console.log('2. Run `npm run test:shared` to test the integration');
    console.log('3. Commit the changes');
  } else {
    console.log('\nNo changes were made. The project may already be integrated with @bluefly/shared.');
  }
}

main();
